PayloadValue

Enum PayloadValue 

#[non_exhaustive]
pub enum PayloadValue { String(String), Integer(i64), Float(f64), Bool(bool), }
Typed scalar payload value stored alongside vector points.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


String(String)

UTF-8 string value.



Integer(i64)

Signed integer value.



Float(f64)

Floating-point value.

Values are validated as finite by store/adaptor request validation before they are accepted for storage or filtering.



Bool(bool)

Boolean value.

Implementations

Source

impl PayloadValue

pub fn as_str(&self) -> Option<&str>

Return the value as a string when it is string-typed.